@@ -117,12 +117,19 @@ class XumlClassDiagram:
             self.logger.info(f'Processing class: {cname}')
             nlayout = np[cname]
             nlayout['wrap'] = nlayout.get('wrap', 1)
-            name_block = TextBlock(cname, nlayout['wrap'])
+            keyletter = c.get('keyletter')
+            keyletter_display = f' {{{keyletter}}}' if keyletter else ''
+            name_block = TextBlock(cname+keyletter_display, nlayout['wrap'])
             h = HorizAlign[nlayout.get('halign', 'CENTER')]
             v = VertAlign[nlayout.get('valign', 'CENTER')]
             # If this is an imported class, append the import reference to the attribute list
             import_subsys_name = c.get('import')
-            internal_ref = [' ', f'(See {import_subsys_name} subsystem)'] if import_subsys_name else []
+            if not import_subsys_name:
+                internal_ref = []
+            elif import_subsys_name.endswith('TBD'):
+                internal_ref = [' ', f'{import_subsys_name.removesuffix(" TBD")} subsystem', '(not yet modeled)']
+            else:
+                internal_ref = [' ', f'(See {import_subsys_name} subsystem)']
             row_span, col_span = nlayout['node_loc']
             # If methods were supplied, include them in content
             # text content includes text for all compartments other than the title compartment
@@ -144,7 +151,7 @@ class XumlClassDiagram:
                 left_col = col_span[0]
                 right_col = left_col if len(col_span) == 1 else col_span[1]
                 nodes[cname] = SpanningNode(
-                    node_type_name='class',
+                    node_type_name='class' if not import_subsys_name else 'imported class',
                     content=text_content,
                     grid=self.flatland_canvas.Diagram.Grid,
                     low_row=low_row, high_row=high_row,
